@@ -53,8 +53,8 @@ class FileProcessor(ABC):
         if response.status_code != HttpCode.OK:
             raise HTTPError(
                 f'{response.status_code} - Unable to upload into={url} with json_string={payload}')
-        paths = ', \n\t'.join([f.path for f in file_data])
-        sysout(f"%GREEN%File(s) [\n\t{paths}\n] successfully uploaded to: {url}%NC%")
+        paths = ', \n  |- '.join([f.path for f in file_data])
+        sysout(f"%GREEN%File(s) [\n  |- {paths}\n] successfully uploaded to: {url}%NC%")
 
         return len(file_data)
 
@@ -92,12 +92,12 @@ class FileProcessor(ABC):
             for entry in data:
                 FileEntry \
                     .of(f"{destination_dir}/{os.path.basename(entry['path'])}", entry['data'], entry['size']).save()
-            paths = ', \n\t'.join([f['path'] for f in data])
+            paths = ', \n  |- '.join([f['path'] for f in data])
         else:
             FileEntry \
                 .of(f"{destination_dir}/{os.path.basename(data['path'])}", data['data'], data['size']).save()
             paths = data['path']
-        sysout(f"%GREEN%File(s) [\n\t{paths}\n] successfully downloaded into: {destination_dir}%NC%")
+        sysout(f"%GREEN%File(s) [\n  |- {paths}\n] successfully downloaded into: {destination_dir}%NC%")
 
     @staticmethod
     def _to_json(file_data: List[FileEntry]) -> str:
