@@ -31,35 +31,47 @@ class FileEntry:
         file_entry.data = file_data
         file_entry.decode()
         file_entry.size = len(file_entry.data)
-        check_state(file_entry.size == expected_size,
-                    "Retrieved data and expected data length mismatch: {} vs {}", expected_size, len(file_entry.data))
+        check_state(
+            file_entry.size == expected_size,
+            f"Received data and expected data sizes mismatch: {file_entry.size} vs {expected_size}")
+
         return file_entry
 
     def __init__(self, file_path: str):
         self.path = file_path
         self.size = 0
         self.data = None
-        if os.path.exists(file_path):
-            self.size = os.path.getsize(file_path)
-            with open(file_path, 'r', encoding='utf-8') as f_in:
-                self.data = f_in.read()
-                check_state(len(self.data) > 0, "File \"{}\" is empty", file_path)
+        self.load()
 
     def __str__(self) -> str:
         return '{"path" : "' + self.path + '", "size" : ' + str(self.size) + ', "data" : "' + self.data + '"}'
 
-    def encode(self) -> 'FileEntry':
-        """B64 Encode this file's data"""
-        self.data = base64.urlsafe_b64encode(self.data.encode(str(Charset.UTF_8))).decode(str(Charset.UTF_8))
-        return self
+    def load(self) -> 'FileEntry':
+        """TODO"""
+        if os.path.exists(self.path):
+            with open(self.path, 'r', encoding='utf-8') as f_in:
+                self.data = f_in.read()
+                self.size = len(self.data)
+                check_state(self.size > 0, "File \"{}\" is empty", self.path)
 
-    def decode(self) -> 'FileEntry':
-        """B64 Decode this file's data"""
-        self.data = str(base64.urlsafe_b64decode(self.data), str(Charset.UTF_8))
         return self
 
     def save(self) -> 'FileEntry':
         """Write current file data into this file"""
-        with open(self.path, 'w', encoding='utf-8') as f_in:
+        with open(self.path, 'w+', encoding='utf-8') as f_in:
             f_in.write(self.data)
+            f_in.flush()
+
+        return self
+
+    def encode(self) -> 'FileEntry':
+        """B64 Encode this file's data"""
+        self.data = str(
+            base64.urlsafe_b64encode(self.data.encode(str(Charset.UTF_8))), encoding=str(Charset.UTF_8))
+        return self
+
+    def decode(self) -> 'FileEntry':
+        """B64 Decode this file's data"""
+        self.data = str(
+            base64.urlsafe_b64decode(self.data), encoding=str(Charset.UTF_8))
         return self
